==> distribution-6.0.0-dev.128.zip: drr/regulation/common/trade/price/functions/IsDefaultPrice.java <==
package drr.regulation.common.trade.price.functions;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperS;
import drr.regulation.common.TransactionReportInstruction;
import drr.regulation.common.functions.IsEquityOther;
import drr.regulation.common.functions.IsVarianceSwap;
import drr.regulation.common.functions.IsVolatilitySwap;
import drr.regulation.common.functions.ProductForEvent;
import drr.standards.iosco.cde.price.reports.PriceNoFormatRule;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(IsDefaultPrice.IsDefaultPriceDefault.class)
public abstract class IsDefaultPrice implements RosettaFunction {
	
	// RosettaFunction dependencies
	//
	@Inject protected IsEquityOther isEquityOther;
	@Inject protected IsVarianceSwap isVarianceSwap;
	@Inject protected IsVolatilitySwap isVolatilitySwap;
	@Inject protected PriceNoFormatRule priceNoFormatRule;
	@Inject protected ProductForEvent productForEvent;

	/**
	* @param transaction 
	* @return isDefaultPrice 
	*/
	public Boolean evaluate(TransactionReportInstruction transaction) {
		Boolean isDefaultPrice = doEvaluate(transaction);
		
		return isDefaultPrice;
	}

	protected abstract Boolean doEvaluate(TransactionReportInstruction transaction);

	public static class IsDefaultPriceDefault extends IsDefaultPrice {
		@Override
		protected Boolean doEvaluate(TransactionReportInstruction transaction) {
			Boolean isDefaultPrice = null;
			return assignOutput(isDefaultPrice, transaction);
		}
		
		protected Boolean assignOutput(Boolean isDefaultPrice, TransactionReportInstruction transaction) {
			isDefaultPrice = ComparisonResult.of(MapperS.of(isVarianceSwap.evaluate(productForEvent.evaluate(transaction)))).or(ComparisonResult.of(MapperS.of(isVolatilitySwap.evaluate(productForEvent.evaluate(transaction))))).or(ComparisonResult.of(MapperS.of(isEquityOther.evaluate(productForEvent.evaluate(transaction)))).and(notExists(MapperS.of(priceNoFormatRule.evaluate(transaction))))).get();
			
			return isDefaultPrice;
		}
	}
}

==> distribution-6.17.1.zip: drr/regulation/common/trade/price/functions/IsDefaultPrice.java <==
package drr.regulation.common.trade.price.functions;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperS;
import drr.regulation.common.TransactionReportInstruction;
import drr.regulation.common.functions.IsEquityOther;
import drr.regulation.common.functions.IsVarianceSwap;
import drr.regulation.common.functions.IsVolatilitySwap;
import drr.regulation.common.functions.ProductForEvent;
import drr.standards.iosco.cde.version3.price.reports.PriceNoFormatRule;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(IsDefaultPrice.IsDefaultPriceDefault.class)
public abstract class IsDefaultPrice implements RosettaFunction {
	
	// RosettaFunction dependencies
	//
	@Inject protected IsEquityOther isEquityOther;
	@Inject protected IsVarianceSwap isVarianceSwap;
	@Inject protected IsVolatilitySwap isVolatilitySwap;
	@Inject protected PriceNoFormatRule priceNoFormatRule;
	@Inject protected ProductForEvent productForEvent;

	/**
	* @param transaction 
	* @return isDefaultPrice 
	*/
	public Boolean evaluate(TransactionReportInstruction transaction) {
		Boolean isDefaultPrice = doEvaluate(transaction);
		
		return isDefaultPrice;
	}

	protected abstract Boolean doEvaluate(TransactionReportInstruction transaction);

	public static class IsDefaultPriceDefault extends IsDefaultPrice {
		@Override
		protected Boolean doEvaluate(TransactionReportInstruction transaction) {
			Boolean isDefaultPrice = null;
			return assignOutput(isDefaultPrice, transaction);
		}
		
		protected Boolean assignOutput(Boolean isDefaultPrice, TransactionReportInstruction transaction) {
			isDefaultPrice = ComparisonResult.of(MapperS.of(isVarianceSwap.evaluate(productForEvent.evaluate(transaction)))).or(ComparisonResult.of(MapperS.of(isVolatilitySwap.evaluate(productForEvent.evaluate(transaction))))).or(ComparisonResult.of(MapperS.of(isEquityOther.evaluate(productForEvent.evaluate(transaction)))).and(notExists(MapperS.of(priceNoFormatRule.evaluate(transaction))))).get();
			
			return isDefaultPrice;
		}
	}
}
